flutter_pdf_export library
Classes
- FontResolver
-
Resolves the correct
pw.Fontfor any Unicode text. - MarkdownParser
- Parses a markdown string into a list of PdfSections.
- PdfBuilder
- The main entry-point for generating PDFs.
- PdfDocumentData
- The top-level data object passed to PdfBuilder.generate.
- PdfSection
- Represents a discrete content block inside a PdfDocumentData.
- PdfStyle
- Controls every visual aspect of the generated PDF.
Enums
- BulletShape
- Shape of the bullet point markers.
- PdfSectionType
- PdfTextAlign
- Alignment for text in the document.
Extensions
- PdfDocumentDataExtension on PdfDocumentData
- PdfExportExtension on String
- Simplifies PDF generation by adding extension methods to String and PdfDocumentData.